context("canvasXpress Web Charts - Meter")


test_that("cXmeter1", {
    check_ui_test(cXmeter1())
})

test_that("cXmeter2", {
    check_ui_test(cXmeter2())
})

test_that("cXmeter3", {
    check_ui_test(cXmeter3())
})

test_that("cXmeter4", {
    check_ui_test(cXmeter4())
})

test_that("cXmeter5", {
    check_ui_test(cXmeter5())
})

test_that("cXmeter6", {
    check_ui_test(cXmeter6())
})

test_that("cXmeter7", {
    check_ui_test(cXmeter7())
})

test_that("cXmeter8", {
    check_ui_test(cXmeter8())
})
